@@ -16,7 +16,9 @@ module GirFFI
 
       def superclass
         # HACK: Inheritance chain is not expressed in GObject's code correctly.
-        return GObject::ObjectClass if info.full_type_name == "GObject::InitiallyUnownedClass"
+        if info.full_type_name == "GObject::InitiallyUnownedClass"
+          return GObject::ObjectClass
+        end
         return parent_field_type.tag_or_class if info.gtype_struct?
         return BoxedBase if GObject.type_fundamental(info.gtype) == GObject::TYPE_BOXED
 
