@@ -53,7 +53,8 @@ describe GObject::Object do
   describe "#set_property" do
     it "raises an error for a property that does not exist" do
       instance = GObject::Object.new
-      _(proc { instance.set_property "foo-bar", 123 }).must_raise GirFFI::PropertyNotFoundError
+      _(proc { instance.set_property "foo-bar", 123 })
+        .must_raise GirFFI::PropertyNotFoundError
     end
   end
 
@@ -103,7 +104,7 @@ describe GObject::Object do
 
   describe "upon garbage collection" do
     it "lowers the reference count" do
-      skip "cannot be reliably tested on JRuby and Rubinius" if jruby? || rubinius?
+      skip "cannot be reliably tested on JRuby" if jruby?
 
       ptr = GObject::Object.new.to_ptr
       _(object_ref_count(ptr)).must_equal 1
